poets package — poets 0.1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- poets 0.1.0 documentation »

# poets package

## Subpackages

- poets.grid package
  - Submodules
  - poets.grid.grids module
  - Module contents
- poets.image package
  - Submodules
  - poets.image.imagefile module
  - poets.image.netcdf module
  - poets.image.resampling module
  - Module contents
- poets.io package
  - Submodules
  - poets.io.download module
  - poets.io.source_base module
  - Module contents
- poets.shape package
  - Submodules
  - poets.shape.shapes module
  - Module contents
- poets.timedate package
  - Submodules
  - poets.timedate.dateindex module
  - poets.timedate.dekad module
  - Module contents

## Submodules

## poets.poet module

This module includes the poets base class Poet.

class `poets.poet.` `Poet`(rootpath, regions=['global'], spatial_resolution=0.25, temporal_resolution='dekad', start_date=datetime.datetime(2000, 1, 1, 0, 0), nan_value=-99, shapefile=None, delete_rawdata=False)

  Bases: `object`

  POETS base class.

  Provides methods to download and resample data using parameters as defined in this class. Resampled outputfiles will be saved as NetCDF4 files.

  Parameters: | rootpath : str path to the directory where data should be stored regions : list of str, optional Identifier of the region in the shapefile. If the default shapefile is used, this would be the FIPS country code. Defaults to global. spatial_resolution : float, optional spatial resolution in degree, defaults to 0.25 temporal_resolution : str, optional temporal resolution of the data, possible values: month, dekad, defaults to dekad start_date : datetime.datetime, optional first date of the dataset, defaults to 2000-01-01 nan_value : int NaN value to use, defaults to -99 shapefile : str, optional Path to shape file, uses “world country admin boundary shapefile” by default. delete_rawdata : bool, optional Original files will be deleted from tmp_path if set True. Defaults to False

  Attributes

  rootpath | (str) path to the directory where data should be stored
  regions | (list of str) Identifier of the region in the shapefile.
  spatial_resolution | (float) Spatial resolution in degree.
  temporal_resolution | (str) Temporal resolution of the data.
  tmp_path | (str) Path where temporary files and original files are stored and downloaded.
  data_path | (str) Path where resampled NetCDF file is stored.
  nan_value | (int) NaN value to use, defaults to -99.
  start_date | (datetime.datetime) First date of the dataset.
  shapefile | (str) Path to shape file.
  sources | (dict of poets.io.BasicSource objects) Sources used by poets given as BasicSource class.
  delete_rawdata | (bool) Original files will be deleted from tmp_path if True.

  Methods

  `add_source`(name, filename, filedate, temp_res, host, protocol, username=None, password=None, port=22, directory=None, dirstruct=None, begin_date=datetime.datetime(2000, 1, 1, 0, 0), variables=['dataset'], nan_value=None)

    Creates BasicSource class and adds it to Poet.sources.

    Parameters: | name : str Name of the data source. filename : str Structure/convention of the file name. filedate : dict Position of date fields in filename, given as tuple. temp_res : str Temporal resolution of the source. host : str Link to data host. protocol : str Protocol for data transfer. username : str, optional Username for data access. password : str, optional Password for data access. port : int, optional Port to data host, defaults to 22. directory : str, optional Path to data on host. dirstruct : list of strings Structure of source directory, each list item represents a subdirectory. begin_date : datetime.date, optional Date from which on data is available, defaults to 2000-01-01. variables : list of strings, optional Variables used from data source, defaults to [‘dataset’]. nan_value : int, float, optional Nan value of the original data as given by the data provider.

  `fetch_data`(begin=None, end=None, delete_rawdata=None)

    Starts download and resampling of input data for sources as added to Poets.sources.

    Parameters: | begin : datetime, optional Start date of data to download, defaults to start date as defined in poets class. end : datetime, optional End date of data to download, defaults to current datetime. delete_rawdata : bool, optional Original files will be deleted from tmp_path if set True. Defaults to delete_rawdata attribute as set in Poet class.

  `get_gridpoints`()

    Returns gridpoints from NetCDF file.

    Parameters: | region : str Identifier of the region in the NetCDF file.
    Returns: | gridpoints : dict of pandas.DataFrame Dict containing Dataframes with gridpoint index as index, longitutes and latitudes as columns for each region.

## Module contents

### Navigation

- index
- modules |
- next |
- previous |
- poets 0.1.0 documentation »